@@ -1,12 +1,12 @@
 package Terse;
-our $VERSION = '0.1234567';
+our $VERSION = '0.12345678';
 use 5.006;
 use strict;
 use warnings;
 no warnings 'redefine';
 use Plack::Request;
 use Plack::Response;
-use JSON;
+use Cpanel::JSON::XS;
 use Scalar::Util qw/reftype/;
 use Time::HiRes qw(gettimeofday);
 use Terse::WebSocket;
@@ -16,7 +16,7 @@ use Struct::WOP qw/all/ => { type => ['UTF-8'], destruct => 1 };
 
 our ($JSON, %PRIVATE);
 BEGIN {
-	$JSON = JSON->new->utf8->canonical(1)->allow_blessed->convert_blessed;
+	$JSON = Cpanel::JSON::XS->new->utf8->canonical(1)->allow_blessed->convert_blessed;
 	%PRIVATE = (
 		map { $_ => 1 } 
 		qw/new run logger logInfo logError websocket delayed_response build_terse content_type raiseError graft pretty serialize DESTROY TO_JSON AUTOLOAD to_app/
@@ -53,6 +53,7 @@ sub run {
 		websocket_class => 'Terse::WebSocket',
 		sock => 'psgix.io',
 		stream_check => 'psgi.streaming',
+		favicon => 'favicon.ico',
 		%args
 	);
 
@@ -64,6 +65,14 @@ sub run {
 		error => \0,
 		errors => [],
 	);
+	
+	if ($j->request->env->{PATH_INFO} =~ m/favicon.ico$/) {
+		return [500, [], []] unless -f $j->_favicon;
+		open my $fh, '<', $j->_favicon;
+		my $favicon = do { local $/; <$fh> };
+		close $fh;
+		return [200, ['Content-Type', 'image/vnd.microsoft.icon'], [$favicon] ];
+	}
 
 	my $content_type = $j->request->content_type;
 	if ($content_type && $content_type =~ m/application\/json/) {
@@ -96,7 +105,7 @@ sub run {
 	};
 
 	my $auth = $j->{_auth};
-	
+
 	my ($session) = $j->_dispatch($auth, $pkg->new());
 	
 	my $req = $j->params->req;
@@ -382,7 +391,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.1234567
+Version 0.12345678
 
 =cut
 
