@@ -9,7 +9,7 @@ use Module::Runtime qw/require_module/;
 
 sub start {
 	my ($pkg, %args) = @_;
-	my $path = $pkg->_path($pkg);
+	my $path = $pkg->_path($pkg, $args{lib});
 	my $self = $pkg->new(
 		app => 1,
 		models => $pkg->_build_models($pkg, $path, $args{lib}),
@@ -85,7 +85,6 @@ sub _build_plugins {
 sub _load_modules {
 	my ($self, %args) = @_;
 	my $type = $args{type};
-	$args{path} =~ s/([^\/]+)$/$args{lib}\/$1/ if ($args{lib});
 	my @modules = map {
 		(my $l = $_) =~ s/^(\/)|(\.pm)$//ig;
 		(my $m = $l) =~ s/\//::/g;
@@ -126,6 +125,7 @@ sub _path {
 	my $pkg_file = join('/', split("\:\:", ($_[1])));
 	my $path = $0;
 	$path =~ s/[^\/]+$//g;
+ 	$path .= $_[2] . '/' if (defined $_[2]);
 	$path .= $pkg_file;
 	return $path;
 }
@@ -187,7 +187,7 @@ Terse::App - Lightweight MVC applications.
 
 =head1 VERSION
 
-Version 0.1234567
+Version 0.12345678
 
 =cut
 
